
/* 4_estimation_rdd. This do-file generates teh RDD estimation sample 
and produces the descriptive statistics and the estimation results 
for the analysis of party affiliation of mayors. */

clear
clear all
set more off

/******************************/
* Globals
/******************************/

/* Working folder*/
global DIR ""

/* Output folder */
global TABLES "$DIR\tables\"
global FIGURES "$DIR\graphs\"

/******************************/
/* Load Municipality Sample */
use "${DIR}\data\sample.dta", replace
/******************************/

/* Sample Selection */
/* at least three years of data */
bysort id_AGS election_period: gen anzahl_jahre = _N
drop if anzahl_jahre < 3

/* Drop jurisdictions with missing information on expenditures */
drop if ln_rev_overall == . | ln_exp_overall == .

/* Excluding kreisfreie Staedte */
capture drop help 
gen help = id_AGS
tostring help, replace
gen help2 = substr(help, strlen(help)-2, strlen(help))
gen krsf_stadt = (help2 == "000")
drop help help2
drop if krsf_stadt == 1

/* Min and Max Population */
bys id_AGS: egen m_pop = mean(pop)
drop if m_pop < 1000 | m_pop > 50000


/* Construction Election Period variables */
local var  ln_exp_overall ln_exp_finanz_all ln_exp_vol rate_tradetax s_exp_general_sp s_exp_people_sp s_exp_culture_sp s_exp_infra_sp ln_pop_1000 ln_besch_wohnort pop_u20 pop_o65 

foreach var in `var' {

sort id_AGS year

bysort id_AGS BM_election_period: egen diff_`var' = mean(`var')

sort id_AGS year 
gen L_diff_`var' = L.diff_`var'

}

/* Drop if LDV is not observed */
drop if L_diff_s_exp_people_sp == .

/* Match Major Data */
merge 1:1 id_AGS year using "${DIR}\data\BM_Data.dta" , keep(1 3) nogenerate
drop _merge

drop if election_period == .
keep if Bundesland == 5 | Bundesland == 9
drop if BM_election != 1

/* Vote Share 2nd after SPD */
egen max_ohne_spd = rowmax(s_cdu s_green s_fdp s_fw s_other)

/* Vote Share 2nd after CDU */
egen max_ohne_cdu = rowmax(s_spd s_green s_fdp s_fw s_other)

/* Running Variable is difference spd to second largest winner */
replace s_spd = s_spd - max_ohne_spd
replace s_cdu = s_cdu - max_ohne_cdu

/* RDD Treatment Local Identification */
gen treatment_spd2 = s_spd > 0
replace treatment_spd2 = . if abs(s_spd) > 0.019

gen treatment_spd25 = s_spd > 0 
replace treatment_spd25 = . if abs(s_spd) > 0.20

/* Control for Share left and right to threshold */
gen s_spd_left = s_spd
replace s_spd_left = 0 if s_spd > 0

gen s_spd_right = s_spd
replace s_spd_right = 0 if s_spd < 0

gen s_spd_left_2 = s_spd_left^2
gen s_spd_right_2 = s_spd_right^2

gen s_cdu_left = s_cdu
replace s_cdu_left = 0 if s_cdu > 0

gen s_cdu_right = s_cdu
replace s_cdu_right = 0 if s_cdu < 0

gen s_cdu_left_2 = s_cdu_left^2
gen s_cdu_right_2 = s_cdu_right^2

/* Placebo */
capture drop tr_placebo_p15
gen tr_placebo_p15 = 0 if s_spd > 0.13 & s_spd < 0.15
replace tr_placebo_p15 = 1 if s_spd >= 0.15 & s_spd < 0.17


/*****************************************************/
/*****************************************************/
/* McCrary Test for SPD and CDU */
/*****************************************************/
/*****************************************************/

/* Figure 1 */
rddensity s_spd , c(0) plot graph_options(xtitle(Victory Margin SPD Mayor Candidate) legend(off) graphregion(color(white)))
graph export "${FIGURES}\RDdensity_SPD.png", as(png) replace

/* Figure 2 */
rddensity s_cdu , c(0) plot graph_options(xtitle(Victory Margin CDU Mayor Candidate) legend(off) graphregion(color(white)))
graph export "${FIGURES}\RDdensity_CDU.png", as(png) replace


/************************************************/
/************************************************/
/* SPD Analysis */
/************************************************/
/************************************************/

/************************************************/
/* Bbandwidth window selection framework developed by Cattaneo, Frandsen and Titiunik (2014) */
/************************************************/

#delimit;
rdwinselect s_spd
L_diff_ln_pop_1000
L_diff_pop_u20
L_diff_pop_o65
L_diff_ln_besch_wohnort
L_diff_ln_exp_overall
L_diff_ln_exp_finanz_all
L_diff_ln_exp_vol
L_diff_rate_tradetax
L_diff_s_exp_general_sp
L_diff_s_exp_people_sp
L_diff_s_exp_culture_sp
L_diff_s_exp_infra_sp
, c(0) wmin(0.013) wstep(0.001) level(0.1);
#delimit cr


/************************************************/
/* Results Local Identification 1.9% */
/************************************************/

cap erase "$TABLES/table7_panel1.tex"
cap erase "$TABLES/table7_panel1.txt"
cap erase "$TABLES/table7_panel1.xml"

cap erase "$TABLES/table7_panel2.tex"
cap erase "$TABLES/table7_panel2.txt"
cap erase "$TABLES/table7_panel2.xml"


forvalues i = 1(1)3 {

	forvalues j = 1(1)7 {

	cap erase "$TABLES/tableB`i'_panel`j'.tex"
	cap erase "$TABLES/tableB`i'_panel`j'.txt"
	cap erase "$TABLES/tableB`i'_panel`j'.xml"

	}

}


local var diff_ln_exp_overall diff_ln_exp_finanz_all diff_ln_exp_vol diff_rate_tradetax diff_s_exp_general_sp diff_s_exp_people_sp diff_s_exp_culture_sp diff_s_exp_infra_sp

foreach var in `var' {

/**********************************/
/* Table 7 */
/**********************************/

/* Baseline */
xi: ivreghdfe `var'  treatment_spd2 , robust
outreg2 using "$TABLES/table7_panel1.tex", append dec (4) tex 

/* With Pre-Determined Variable */
xi: ivreghdfe `var'  treatment_spd2 L_`var' , robust
outreg2 using "$TABLES/table7_panel2.tex", append dec (4) tex  


/**********************************/
/* Table B1 */
/**********************************/

/* Placebo Different Threshold 15 */
xi: ivreghdfe `var'  tr_placebo_p15 L_`var' , robust
outreg2 using "$TABLES/tableB1_panel1.tex", append dec (4) tex  

/* Pre-Determined (Last Election Period) */
xi: ivreghdfe L_`var'  treatment_spd2 , robust
outreg2 using "$TABLES/tableB1_panel2.tex", append dec (4) tex  

/* Different Victory Margin 20\%, Linear Victory Margin Control */
xi: ivreghdfe `var'  treatment_spd25 s_spd_left s_spd_right, robust
outreg2 using "$TABLES/tableB1_panel3.tex", append dec (4) tex  

/* Different Victory Margin 20\%, Quadratic Victory Margin Control */
xi: ivreghdfe `var'  treatment_spd25 s_spd_left s_spd_right s_spd_left_2 s_spd_right_2, robust
outreg2 using "$TABLES/tableB1_panel4.tex", append dec (4) tex  

/* Different Victory Margin 20\%, Linear Victory Margin Control and LDV */
xi: ivreghdfe `var'  treatment_spd25 s_spd_left s_spd_right L_`var', robust
outreg2 using "$TABLES/tableB1_panel5.tex", append dec (4) tex  

/* Different Victory Margin 20\%, Quadratic Victory Margin Control and LDV */
xi: ivreghdfe `var'  treatment_spd25 s_spd_left s_spd_right s_spd_left_2 s_spd_right_2 L_`var', robust
outreg2 using "$TABLES/tableB1_panel6.tex", append dec (4) tex 

}


/**********************************/
/* Figure B1 to B8 */
/**********************************/

local var ln_exp_overall ln_exp_finanz_all ln_exp_vol rate_tradetax s_exp_general_sp s_exp_people_sp s_exp_culture_sp s_exp_infra_sp 

foreach var in `var' {

rdrobust diff_`var' s_spd, p(1) c(0)
rdplot diff_`var'  s_spd  if abs(s_spd) < `e(h_r)', kernel(triangular) c(0) p(2) binselect(esmvpr) h(`e(h_r)') graph_options(title("") legend(off) xtitle(Victory Margin SPD Mayor Candidate) graphregion(color(white)))
graph export "${FIGURES}\spd_plot_`var'.png", as(png) replace

}


/**********************************/
/* Table B2 */
/**********************************/

local var diff_ln_pop_1000 diff_pop_u20 diff_pop_o65 diff_ln_besch_wohnort

foreach var in `var' {

/* Sample and Specification as in Panel 1 Table 7 */
xi: ivreghdfe L_`var'  treatment_spd2, robust
outreg2 using "$TABLES/tableB2_panel1.tex", append dec (4) tex 

/* Sample and Specification as in Panel 4 Table B1 */
xi: ivreghdfe L_`var'  treatment_spd25 s_spd_left s_spd_right s_spd_left_2 s_spd_right_2, robust
outreg2 using "$TABLES/tableB2_panel2.tex", append dec (4) tex 

/* Sample and Specification as in Panel 1 Table B3 */
rdrobust L_`var'  s_spd , c(0) p(1) 
rdrobust L_`var'  s_spd , c(0) p(2) h(`e(h_l)') b(`e(h_l)') 
outreg2 using "$TABLES/tableB2_panel3.tex", append dec (4) tex  adds(BC,   e(tau_bc), se1, e(ci_l_rb) , se2, e(ci_r_rb) , bw, e(h_l), bias, e(b_l))

}


/**********************************/
/* Table B3 */
/**********************************/

local var diff_ln_exp_overall diff_ln_exp_finanz_all diff_ln_exp_vol diff_rate_tradetax diff_s_exp_general_sp diff_s_exp_people_sp diff_s_exp_culture_sp diff_s_exp_infra_sp

foreach var in `var' {

/* Local quadratic polynomial */
rdrobust `var'  s_spd , c(0) p(1) 
rdrobust `var'  s_spd , c(0) p(2) h(`e(h_l)') b(`e(h_l)') 
outreg2 using "$TABLES/tableB3_panel1.tex", append dec (4) tex  adds(BC,   e(tau_bc), se1, e(ci_l_rb) , se2, e(ci_r_rb) , bw, e(h_l), bias, e(b_l))

/* Last election period & Local quadratic polynomial */
rdrobust L_`var'  s_spd , c(0) p(1) 
rdrobust L_`var'  s_spd , c(0) p(2) h(`e(h_l)') b(`e(h_l)')
outreg2 using "$TABLES/tableB3_panel2.tex", append dec (4) tex adds(BC,   e(tau_bc), se1, e(ci_l_rb) , se2, e(ci_r_rb) , bw, e(h_l), bias, e(b_l))

/* Local quadratic polynomial and LDV */
rdrobust `var'  s_spd , c(0) p(1) covs(L_`var')
rdrobust `var'  s_spd , c(0) p(2) covs(L_`var') h(`e(h_l)') b(`e(h_l)')
outreg2 using "$TABLES/tableB3_panel3.tex", append dec (4) tex  adds(BC,   e(tau_bc), se1, e(ci_l_rb) , se2, e(ci_r_rb) , bw, e(h_l), bias, e(b_l))

/* Local quadratic polynomial and LDV */
rdrobust `var'  s_spd , c(0) p(2) covs(L_`var') 
outreg2 using "$TABLES/tableB3_panel4.tex", append dec (4) tex  

/* Placebo Threshold 15\% */
rdrobust `var'  s_spd , c(0.15) p(1) covs(L_`var')
rdrobust `var'  s_spd , c(0.15) p(2) covs(L_`var') h(`e(h_l)') b(`e(h_l)')
outreg2 using "$TABLES/tableB3_panel5.tex", append dec (4) tex adds(BC,   e(tau_bc), se1, e(ci_l_rb) , se2, e(ci_r_rb) , bw, e(h_l), bias, e(b_l))

/* Local cubic polynomial */
rdrobust `var'  s_spd , c(0) p(2) covs(L_`var')
rdrobust `var'  s_spd , c(0) p(3) covs(L_`var') h(`e(h_l)') b(`e(h_l)') 
outreg2 using "$TABLES/tableB3_panel6.tex", append dec (4) tex  adds(BC,   e(tau_bc), se1, e(ci_l_rb) , se2, e(ci_r_rb) , bw, e(h_l), bias, e(b_l))

}


